#!/usr/bin/python
# coding: utf-8

#--------------------------------------------------------------------
# Fichero:  fn-comenta.py
# Objetivo: Comentar las fotos de un directorio
# Autor:    Pedro Reina <pedro@pedroreina.net>
# Fecha:    X.14.10.2015
# Licencia: Dominio público
#--------------------------------------------------------------------

#------------------------------------------------
# Constantes del programa
#------------------------------------------------

#------------------------------------------------
# Módulos necesarios
#------------------------------------------------

# Para leer la línea de órdenes
import sys

# Para leer el contenido de un directorio
# Para ejecutar órdenes del sistema
import os

# Para manejar expresiones regulares
import re

# Para el GUI
from PyQt4 import QtGui, QtCore

# Para poder usar Unicode en llamadas al sistema
import subprocess

#------------------------------------------------
# Variables globales
#------------------------------------------------

TotalImagen = 0;     # Número de imágenes en el directorio
ListaImagenes = []   # Los nombres de los archivos de imagen
ImagenActual = None

#------------------------------------------------
# Funciones
#------------------------------------------------

#------------------------------------------------
# Analiza el directorio actual
def AnalizaDirectorio():

  # Obtenemos la lista de archivos del directorio
  ListaArchivos = os.listdir ('.')

  # Recorremos la lista buscando archivos JPG
  ExpresionRegular = re.compile ('\.jpeg$', re.IGNORECASE)
  for Archivo in ListaArchivos:
    if ( ExpresionRegular.search (Archivo) ):
      ListaImagenes.append (Archivo)

  # Calculamos cuántos archivos hemos encontrado
  return ( len (ListaImagenes) )

#------------------------------------------------
# Pasa a la siguiente imagen
def Siguiente():
  global ImagenActual

  ImagenActual += 1
  if ( ImagenActual == TotalImagen ):
    ImagenActual = TotalImagen - 1

  ActualizaImagen()

#------------------------------------------------
# Pasa a la anterior imagen
def Anterior():
  global ImagenActual

  ImagenActual -= 1
  if ( ImagenActual == -1 ):
    ImagenActual = 0

  ActualizaImagen()

#------------------------------------------------
# Pasa a la primera imagen
def Primera():
  global ImagenActual
  ImagenActual = 0
  ActualizaImagen()

#------------------------------------------------
# Pasa a la última imagen
def Ultima():
  global ImagenActual
  ImagenActual = TotalImagen - 1
  ActualizaImagen()

#------------------------------------------------
# Actualiza la imagen mostrada
def ActualizaImagen():
  # El archivo que contiene la imagen
  Archivo = ListaImagenes[ImagenActual]

  # Actualizamos la imagen
  Imagen = QtGui.QPixmap(Archivo)
  VisorImagen.setPixmap (Imagen)

  # Actualizamos la descripción de la imagen
  Texto = u'Fotografía ' + str (ImagenActual+1) + ' de ' + str(TotalImagen)
  Texto += '; archivo: ' + Archivo
  EtiquetaDirectorio.setText (Texto)

  # Actualizamos el comentario
  Orden = 'rdjpgcom -raw ' + Archivo
  Texto = os.popen(Orden).read()
  Texto = unicode (Texto, "utf-8")
  Editor.setPlainText (Texto)

#------------------------------------------------
# Graba el comentario en la imagen actual
def Graba():
  # Recuperamos el comentario escrito en el GUI
  Texto = Editor.toPlainText()

  # Lo manejamos como UTF-8
  Texto = unicode (Texto.toUtf8(), "utf-8")

  # Lo grabamos en la imagen
  Archivo = ListaImagenes[ImagenActual]
  os.system ("cp " + Archivo + " tmp")
  Orden = 'wrjpgcom -replace -comment "' + Texto + '" tmp > ' + Archivo
  subprocess.call (Orden, shell=True)
  os.system ("rm tmp")

#------------------------------------------------
# El programa
#------------------------------------------------

# Analizamos el directorio en el que nos han ejecutado
TotalImagen = AnalizaDirectorio()

# Ordenamos la lista de imágenes encontradas
ListaImagenes.sort()

# Esta es una aplicación Qt
Aplicacion = QtGui.QApplication (sys.argv)

# Mensajes en español si están disponibles
Traductor = QtCore.QTranslator()
if Traductor.load ("/usr/share/qt4/translations/qt_es.qm"):
  Aplicacion.installTranslator (Traductor)

# La ventana principal de la aplicación
Ventana = QtGui.QWidget()

# La caja con el informe de la imagen
EtiquetaDirectorio = QtGui.QLabel ("")
CajaDirectorio = QtGui.QVBoxLayout()
CajaDirectorio.addStretch (1)
CajaDirectorio.addWidget (EtiquetaDirectorio)
GrupoDirectorio = QtGui.QGroupBox (u"Datos de la fotografía")
GrupoDirectorio.setLayout (CajaDirectorio)

# La imagen
Imagen = QtGui.QPixmap(ListaImagenes[0])
VisorImagen = QtGui.QLabel()
VisorImagen.setAlignment (QtCore.Qt.AlignCenter)
VisorImagen.setPixmap (Imagen)

# La caja con los botones de orden
BotonPrimera = QtGui.QPushButton ("Primera")
BotonAnterior = QtGui.QPushButton ("Anterior")
BotonSiguiente = QtGui.QPushButton ("Siguiente")
BotonUltima = QtGui.QPushButton (u"Última")
BotonGrabar = QtGui.QPushButton ("Grabar")
BotonCerrar = QtGui.QPushButton ("Cerrar")
CajaBotones = QtGui.QHBoxLayout()
CajaBotones.addWidget (BotonPrimera)
CajaBotones.addWidget (BotonAnterior)
CajaBotones.addWidget (BotonSiguiente)
CajaBotones.addWidget (BotonUltima)
CajaBotones.addWidget (BotonGrabar)
CajaBotones.addWidget (BotonCerrar)

# La caja con el comentario
Editor = QtGui.QPlainTextEdit()

# El contenedor principal es un contenedor vertical
CajaVertical = QtGui.QVBoxLayout()
CajaVertical.addStretch (1)
CajaVertical.addWidget (GrupoDirectorio)
CajaVertical.addWidget (VisorImagen)
CajaVertical.addLayout (CajaBotones)
CajaVertical.addWidget (Editor)
CajaVertical.setSizeConstraint (QtGui.QLayout.SetFixedSize)
Ventana.setLayout (CajaVertical)

# Conectamos las señales con sus respuestas
BotonCerrar.clicked.connect (Ventana.close)
QtCore.QObject.connect (BotonGrabar, QtCore.SIGNAL("clicked()"), Graba)
QtCore.QObject.connect (BotonSiguiente, QtCore.SIGNAL("clicked()"), Siguiente)
QtCore.QObject.connect (BotonAnterior, QtCore.SIGNAL("clicked()"), Anterior)
QtCore.QObject.connect (BotonPrimera, QtCore.SIGNAL("clicked()"), Primera)
QtCore.QObject.connect (BotonUltima, QtCore.SIGNAL("clicked()"), Ultima)

# Nos colocamos en la primera imagen
ImagenActual = 0
ActualizaImagen()

# Mostramos la ventana
Ventana.setWindowTitle ('fn-comenta.py')
Ventana.setGeometry (10, 10, 10, 10)
Ventana.show()

# Cuando nos digan, terminaremos
sys.exit (Aplicacion.exec_())
