#!/usr/bin/python
# coding: utf-8

#--------------------------------------------------------------------
# Fichero:  fn-descarga.py
# Objetivo: Descargar las fotos de un directorio
# Autor:    Pedro Reina <pedro@pedroreina.net>
# Fecha:    D.6.9.2015
# Licencia: Dominio público
#--------------------------------------------------------------------

#------------------------------------------------
# Constantes del programa
#------------------------------------------------

# El ejecutable jhead
jhead = '/usr/bin/jhead'

#------------------------------------------------
# Módulos necesarios
#------------------------------------------------

# Para leer la línea de órdenes
import sys

# Para leer el contenido de un directorio
# Para ejecutar órdenes externas
import os

# Para manejar expresiones regulares
import re

# Para copiar archivos
import shutil

#------------------------------------------------
# Variables globales
#------------------------------------------------

#------------------------------------------------
# Funciones
#------------------------------------------------

#------------------------------------------------
# Devuelve el momento en que se tomó una imagen
def Momento (Archivo):
  # La orden que hay que ejecutar
  Orden = jhead + ' ' + Archivo + ' | grep Date | cut -c 16-36'
  Info = os.popen(Orden).read()

  # Eliminamos el fin de línea
  Info = Info.replace ('\n', '')

  # Cambiamos espacios y dos puntos por guiones
  Info = Info.replace (' ', '-')
  Info = Info.replace (':', '-')

  # Devolvemos el resultado
  return Info

#------------------------------------------------
# Prepara un nombre de archivo
def PreparaNombre (Base, Num):
  return Base + '-' + str(Num) + '.jpg'

#------------------------------------------------
# El programa
#------------------------------------------------

# Informamos al usuario
print "fn-descarga.py"
print "=============="

# Si no hay un argumento, ayuda al usuario
if ( len(sys.argv) < 2 ):
  print "Es necesario indicar el nombre del directorio"

# Si nos mandan un argumento, es el directorio
else:
  Directorio = sys.argv[1]
  print "Directorio: " + Directorio

  # Obtenemos la lista de archivos del directorio
  ListaArchivos = os.listdir (Directorio)

  # La lista con las imágenes que encontremos
  ListaImagenes = []

  # Recorremos la lista buscando archivos JPG
  ExpresionRegular = re.compile ('\.jpg$', re.IGNORECASE)
  for Archivo in ListaArchivos:
    if ( ExpresionRegular.search (Archivo) ):
      ListaImagenes.append (Archivo)

  # Informamos de cuántos archivos hemos encontrado
  TotalImagen = len (ListaImagenes)
  print "El directorio contiene " + str(TotalImagen) + " imágenes"

  if ( TotalImagen > 0 ):
    # Ordenamos la lista
    ListaImagenes.sort()

    # Para cada imagen encontrada
    i = 1
    for Archivo in ListaImagenes:
      # Consultamos el dato EXIF de cuándo se tomó la foto
      NombreCompleto = Directorio + '/' + Archivo
      Codigo = Momento (NombreCompleto)

      # Buscamos un nombre para el nuevo archivo
      Numero = 1
      Nuevo = PreparaNombre (Codigo, Numero)
      while ( os.path.isfile(Nuevo) ):
        Numero += 1
        Nuevo = PreparaNombre (Codigo, Numero)

      # Copiamos el archivo
      print str(i) + '/' + str(TotalImagen) + ': ' + Archivo + ' => ' + Nuevo
      shutil.copy2 (NombreCompleto, Nuevo)
      i += 1

# Hemos acabado; informamos al usuario
print "Terminado."
