#!/usr/bin/python
# coding: utf-8

#--------------------------------------------------------------------
# Fichero:  fn-prepara.py
# Objetivo: Preparar las fotos de un directorio
# Autor:    Pedro Reina <pedro@pedroreina.net>
# Fecha:    J.15.10.2015
# Licencia: Dominio público
#--------------------------------------------------------------------

#------------------------------------------------
# Constantes del programa
#------------------------------------------------

MaxAnchuraInd = 780; # Máxima anchura del índice (sólo al sugerir)
Mayor43 = 540;       # Lado mayor sugerido para las imágenes medianas
Mayor32 = 540;       # (para los formatos 4:3 y 3:2)

CalidadMedianas = 85 # Calidad jpg sugerida para las imágenes medianas
CalidadIndice = 100  # Calidad jpg sugerida para el índice

#------------------------------------------------
# Módulos necesarios
#------------------------------------------------

# Para leer la línea de órdenes
import sys

# Para leer el contenido de un directorio
# Para ejecutar órdenes del sistema
import os

# Para manejar expresiones regulares
import re

# Para el GUI
from PyQt4 import QtGui, QtCore

# Para calcular la raíz cuadrada
import math

#------------------------------------------------
# Variables globales
#------------------------------------------------

TotalImagen = 0;     # Número de imágenes en el directorio
Formato = None;      # Puede ser 43, 32 o 0
ListaImagenes = []   # Los nombres de los archivos de imagen

# Cuántas fotos hay de cada formato
TotalFormato43 = 0;
TotalFormato32 = 0;
TotalFormatoLibre = 0;

# Dimensiones
Columnas = 0
Filas = 0
Anchura = 0
Altura = 0
Mayor = 0
Menor = 0

# Dimensiones del índice
AnchuraInd = 0
AlturaInd = 0
Huecos = 0

# Incrementos de cada dimension
IncrementoAnchura = 0
IncrementoAltura = 0

#------------------------------------------------
# Funciones
#------------------------------------------------

#------------------------------------------------
# Analiza el directorio actual
def AnalizaDirectorio():

  # Obtenemos la lista de archivos del directorio
  ListaArchivos = os.listdir ('.')

  # Recorremos la lista buscando archivos JPG
  ExpresionRegular = re.compile ('\.jpg$', re.IGNORECASE)
  for Archivo in ListaArchivos:
    if ( ExpresionRegular.search (Archivo) ):
      ListaImagenes.append (Archivo)

  # Calculamos cuántos archivos hemos encontrado
  return ( len (ListaImagenes) )

#------------------------------------------------
# Averigua el formato mayoritario de las imágenes
def AveriguaFormato():
  global TotalFormato32, TotalFormato43, TotalFormatoLibre, \
          IncrementoAnchura, IncrementoAltura

  # Vemos y anotamos el formato de cada imagen
  for Archivo in ListaImagenes:
    FormatoImagen = AveriguaFormatoImagen (Archivo)

    if ( FormatoImagen == 43 ):
      TotalFormato43 += 1
    if ( FormatoImagen == 32 ):
      TotalFormato32 += 1
    if ( FormatoImagen == 0 ):
      TotalFormatoLibre += 1

  # Averiguamos el formato mayoritario
  if ( TotalFormatoLibre >= TotalFormato32 and
       TotalFormatoLibre >= TotalFormato43 ):
    Formato = 0
    IncrementoAnchura = 1
    IncrementoAltura = 1

  if ( TotalFormato43 >= TotalFormato32 and
       TotalFormato43 >= TotalFormatoLibre ):
    Formato = 43
    IncrementoAnchura = 4
    IncrementoAltura = 3

  if ( TotalFormato32 >= TotalFormato43 and
       TotalFormato32 >= TotalFormatoLibre ):
    Formato = 32
    IncrementoAnchura = 3
    IncrementoAltura = 2

  # Devolvemos el resultado de nuestro estudio
  return ( Formato )

#------------------------------------------------
# Sugiere unas dimensiones para todo
def SugiereDimensiones():
  global Columnas, Filas, Anchura, Altura, Mayor, Menor, \
          AnchuraInd, AlturaInd, Huecos

  # Para calcular las columnas y filas del índice comenzamos
  # por el mínimo cuadrado que pueda contener todas las imágenes
  Lado = (int) (math.sqrt(TotalImagen))
  if ( Lado != math.sqrt(TotalImagen) ):
    Lado += 1
  Columnas = Lado;
  Filas = Lado;

  # y quitamos las filas que sobren
  while ( Columnas * Filas - TotalImagen >= Lado ):
    Filas -= 1

  # Dimensiones de las imágenes medianas
  if ( Formato == 43 ):
    Mayor = Mayor43
  if ( Formato == 32 ):
    Mayor = Mayor32
  if ( Formato == 0 ):
    Mayor = Mayor43;
    Menor = Mayor43;
  Menor = MenorSegunFormato (Mayor, Menor)

  # Dimensiones de las miniaturas
  Anchura = (int) (MaxAnchuraInd/Columnas)
  Anchura = Reduce (Anchura, IncrementoAnchura)
  Altura = MenorSegunFormato (Anchura, Altura)

  # Dimensiones del índice
  (AnchuraInd, AlturaInd, Huecos) = CalculaIndice (Anchura, Altura, Columnas, Filas)

#------------------------------------------------
# Calcula las dimensiones del índice
def CalculaIndice (Anchura, Altura, Columnas, Filas):
  return (Anchura * Columnas, Altura * Filas, Columnas * Filas - TotalImagen)

#------------------------------------------------
# Calcula un valor menor a partir del mayor, respetando el formato
def MenorSegunFormato (Mayor, Menor):
  if ( Formato == 43 ):
    Menor = 3 * Mayor / 4

  if ( Formato == 32 ):
    Menor = 2 * Mayor / 3

  return ( Menor )

#-------------------------------------------------
# Calcula un valor mayor a partir del menor, respetando el formato
def MayorSegunFormato (Mayor, Menor):
  if ( Formato == 43 ):
    Mayor = 4 * Menor / 3

  if ( Formato == 32 ):
    Mayor = 3 * Menor / 2

  return ( Mayor )

#------------------------------------------------
# Reduce un valor hasta que sea divisible por el divisor dado
def Reduce (Numero, Divisor):
  while ( Numero % Divisor ):
    Numero -= 1

  return ( Numero )

#------------------------------------------------
# Averigua las dimensiones de una imagen
def AveriguaDimensionesImagen (Archivo):
  # La orden que hay que ejecutar
  Orden = 'jhead ' + Archivo + ' | grep Resolution'
  Info = os.popen(Orden).read()

  # Descomponemos la contestación
  ListaInfo = Info.split()

  # Averiguamos las dimensiones de la imagen
  Anchura = (int)(ListaInfo[2])
  Altura = (int)(ListaInfo[4])

  # Y contestamos
  return (Anchura, Altura)

#------------------------------------------------
# Averigua el formato de una imagen
def AveriguaFormatoImagen (Archivo):
  # Averiguamos las dimensiones de la imagen
  (Anchura, Altura) = AveriguaDimensionesImagen (Archivo)

  # Puede estar en vertical
  if ( Anchura > Altura ):
    Mayor = Anchura
    Menor = Altura
  else:
    Mayor = Altura
    Menor = Anchura

  # Calculamos su formato
  Respuesta = 0

  if ( Mayor/4 == Menor/3 ):
    Respuesta = 43

  if ( Mayor/3 == Menor/2 ):
    Respuesta = 32

  # Y contestamos
  return Respuesta

#------------------------------------------------
# Controla la situación ante cambios en Anchura
def ManejaAnchura():
  # Tomamos los valores actuales del GUI
  Anchura = SpinAnchura.value()
  Altura = SpinAltura.value()

  # Calculamos los nuevos valores
  Anchura = Reduce (Anchura, IncrementoAnchura)
  Altura = MenorSegunFormato (Anchura, Altura)

  # Actualizamos el GUI
  ActualizaAnchuraAltura (Anchura, Altura)

  # Actualizamos el índice
  ActualizaIndice()

#------------------------------------------------
# Controla la situación ante cambios en Altura
def ManejaAltura():
  # Tomamos los valores actuales del GUI
  Anchura = SpinAnchura.value()
  Altura = SpinAltura.value()

  # Calculamos los nuevos valores
  Altura = Reduce (Altura, IncrementoAltura);
  Anchura = MayorSegunFormato (Anchura, Altura);

  # Actualizamos el GUI
  ActualizaAnchuraAltura (Anchura, Altura)

  # Actualizamos el índice
  ActualizaIndice()

#------------------------------------------------
# Actualiza Anchura y Altura a la vez
def ActualizaAnchuraAltura (Anchura, Altura):
  global SpinAnchura, SpinAltura

  SpinAltura.blockSignals (True)
  SpinAnchura.blockSignals (True)
  SpinAnchura.setValue (Anchura)
  SpinAltura.setValue (Altura)
  SpinAltura.blockSignals (False)
  SpinAnchura.blockSignals (False)

#------------------------------------------------
# Actualiza en el GUI los datos del índice
def ActualizaIndice():
  # Tomamos los valores actuales del GUI
  Anchura = SpinAnchura.value()
  Altura = SpinAltura.value()
  Columnas = SpinColumnas.value()
  Filas = SpinFilas.value()

  # Dimensiones del índice
  (AnchuraInd, AlturaInd, Huecos) = CalculaIndice (Anchura, Altura, Columnas, Filas)

  # Actualizamos el GUI
  EtiquetaAnchura.setText (u'Anchura: ' + str(AnchuraInd))
  EtiquetaAltura.setText (u'Altura: ' + str(AlturaInd))
  EtiquetaHuecos.setText (u'Huecos: ' + str(Huecos))

#------------------------------------------------
# Actualiza en el GUI los datos del porcentaje
def ActualizaPorcentaje (Valor):
  Ventana.setWindowTitle ('(' + str(Valor) + '%) fn-prepara.py')
  BarraProgreso.setValue (Valor)

#------------------------------------------------
# Controla la situación ante cambios en Mayor
def ManejaMayor():
  global SpinMayor, SpinMenor

  # Tomamos los valores actuales del GUI
  Mayor = SpinMayor.value()
  Menor = SpinMenor.value()

  # Calculamos los nuevos valores
  Mayor = Reduce (Mayor, IncrementoAnchura)
  Menor = MenorSegunFormato (Mayor, Menor)

  # Actualizamos el GUI
  ActualizaMayorMenor (Mayor, Menor)

#------------------------------------------------
# Controla la situación ante cambios en Menor
def ManejaMenor():
  global SpinMayor, SpinMenor

  # Tomamos los valores actuales del GUI
  Mayor = SpinMayor.value()
  Menor = SpinMenor.value()

  # Calculamos los nuevos valores
  Menor = Reduce (Menor, IncrementoAltura);
  Mayor = MayorSegunFormato (Mayor, Menor);

  # Actualizamos el GUI
  ActualizaMayorMenor (Mayor, Menor)

#------------------------------------------------
# Actualiza Mayor y Menor a la vez
def ActualizaMayorMenor (Mayor, Menor):
  global SpinMayor, SpinMenor

  SpinMayor.blockSignals (True)
  SpinMenor.blockSignals (True)
  SpinMayor.setValue (Mayor)
  SpinMenor.setValue (Menor)
  SpinMayor.blockSignals (False)
  SpinMenor.blockSignals (False)

#------------------------------------------------
# Prepara las imágenes
def Prepara():
  # Informamos al usuario
  EtiquetaEstado.setText (u'El programa está trabajando')
  ActualizaPorcentaje (0)

  # Tomamos los ocho parámetros del GUI
  AnchuraMini = SpinAnchura.value()
  AlturaMini = SpinAltura.value()
  Columnas = SpinColumnas.value()
  Filas = SpinFilas.value()
  CalidadIndice = SpinCalidadMiniaturas.value()
  Mayor = SpinMayor.value()
  Menor = SpinMenor.value()
  CalidadMedianas = SpinCalidadMedianas.value()

  # Dimensiones de la imagen índice
  AnchuraIndice = AnchuraMini * Columnas
  AlturaIndice = AlturaMini * Filas

  # Trabajamos con cada archivo de imagen:
  #   Lo copiamos como tmp(NombreAnterior) y siempre apaisado
  #   Creamos una imagen reducida con extensión jpeg
  #   Creamos una imagen miniatura con extensión png
  NumeroArchivo = 1
  for Archivo in ListaImagenes:
    ActualizaPorcentaje (90*NumeroArchivo/TotalImagen)
    EtiquetaDesarrollo.setText ('Reduciendo imagen ' + str(NumeroArchivo))
    NumeroArchivo += 1

    # Creamos una copia de la imagen, rotándola si es necesario
    (Anchura, Altura) = AveriguaDimensionesImagen (Archivo)
    if ( Anchura > Altura ):
      os.system ("cp " + Archivo + " tmp" + Archivo)
      Dimensiones = str(Mayor) + "x" + str(Menor)
    else:
      os.system ("jpegtran -rotate 90 " + Archivo + ">tmp" + Archivo)
      Dimensiones = str(Menor) + "x" + str(Mayor)

    # Creamos la imagen mediana, con extensión "jpeg", a partir del original
    Orden = "mogrify -format jpeg -geometry " + Dimensiones + " -quality " + \
            str(CalidadMedianas) + " " + Archivo
    os.system (Orden)

    # Creamos la miniatura, con extensión "png", a partir de la copia
    Dimensiones = str(AnchuraMini) + "x" + str(AlturaMini)
    Orden = "mogrify -format png -geometry " + Dimensiones + \
            " -quality 100 tmp" + Archivo
    os.system (Orden)

    # Borramos la copia
    os.system ("rm tmp" + Archivo)

  # Creamos el índice
  ActualizaPorcentaje (90)
  EtiquetaDesarrollo.setText (u"Creando índice")

  # El trabajo duro lo hace montage
  Dimensiones = str(AnchuraMini) + "x" + str(AlturaMini)
  Cuadro = str(Columnas) + "x" + str(Filas)
  Orden = "montage +frame +shadow +label -geometry " + Dimensiones + \
          "! -tile " + Cuadro + " tmp*.png indicetmp.png"
  os.system (Orden)

  # Convertimos a JPG
  os.system ("mogrify -format jpg indicetmp.png -quality " + str(CalidadIndice))

  # Y añadimos como comentario el número de columnas y filas
  Comentario = str(Columnas) + " " + str(Filas)
  Orden = "wrjpgcom -comment '" + Comentario + "' indicetmp.jpg > indice.jpg"
  os.system (Orden)

  # Borramos los archivos temporales que hemos necesitado
  ActualizaPorcentaje (98)
  EtiquetaDesarrollo.setText ("Borrando archivos temporales")
  os.system ("rm tmp* indicetmp.*")

  # Hemos acabado
  ActualizaPorcentaje (100)
  EtiquetaDesarrollo.setText ('Esperando al usuario')
  EtiquetaEstado.setText ('El programa ha terminado')

#------------------------------------------------
# Cambia el formato a 4:3
def Cambia43():
  global Formato, IncrementoAltura, IncrementoAnchura

  Formato = 43
  IncrementoAnchura = 4
  IncrementoAltura = 3
  ModificaDimensiones()

#------------------------------------------------
# Cambia el formato a 3:2
def Cambia32():
  global Formato, IncrementoAltura, IncrementoAnchura

  Formato = 32
  IncrementoAnchura = 3
  IncrementoAltura = 2
  ModificaDimensiones()

#------------------------------------------------
# Cambia el formato a Libre
def CambiaLibre():
  global Formato, IncrementoAltura, IncrementoAnchura

  Formato = 0
  IncrementoAnchura = 1
  IncrementoAltura = 1
  ModificaDimensiones()

#------------------------------------------------
# Modifica las dimennsiones tras un cambio de formato
def ModificaDimensiones():
  global Anchura, Altura, Mayor, Menor, SpinMayor, SpinMenor, \
          SpinAltura, SpinAnchura

  # Ajustamos los valores
  Anchura = Reduce (Anchura, IncrementoAnchura)
  Altura = MenorSegunFormato (Anchura, Altura)
  Mayor = Reduce (Mayor, IncrementoAnchura)
  Menor = MenorSegunFormato (Mayor, Menor)
  SpinMayor.setSingleStep (IncrementoAnchura)
  SpinMenor.setSingleStep (IncrementoAltura)
  SpinAnchura.setSingleStep (IncrementoAnchura)
  SpinAltura.setSingleStep (IncrementoAltura)

  # Actualizamos el GUI
  ActualizaAnchuraAltura (Anchura, Altura)
  ActualizaMayorMenor (Mayor, Menor)

  # Actualizamos el índice
  ActualizaIndice()

#------------------------------------------------
# El programa
#------------------------------------------------

# Analizamos el directorio en el que nos han ejecutado
TotalImagen = AnalizaDirectorio()

# Si hay imágenes, calculamos los datos que vamos a sugerir
if ( TotalImagen > 0 ):
  # Ordenamos la lista
  ListaImagenes.sort()

  # Averiguamos el formato mayoritario
  Formato = AveriguaFormato()

  # Sugerimos unas dimensiones
  SugiereDimensiones()

# Esta es una aplicación Qt
Aplicacion = QtGui.QApplication (sys.argv)

# Mensajes en español si están disponibles
Traductor = QtCore.QTranslator()
if Traductor.load ("/usr/share/qt4/translations/qt_es.qm"):
  Aplicacion.installTranslator (Traductor)

# La ventana principal de la aplicación
Ventana = QtGui.QWidget()

# La caja con el informe del directorio
Texto = 'El directorio tiene ' + str(TotalImagen) + u' fotografías'
EtiquetaDirectorio = QtGui.QLabel (Texto)
CajaDirectorio = QtGui.QVBoxLayout()
CajaDirectorio.addStretch (1)
CajaDirectorio.addWidget (EtiquetaDirectorio)
GrupoDirectorio = QtGui.QGroupBox(u"Directorio")
GrupoDirectorio.setLayout (CajaDirectorio)

# La caja con los grupos Formato y Medianas
GrupoBotonesFormato=QtGui.QButtonGroup()
Boton43=QtGui.QRadioButton('4:3 (' + str(TotalFormato43) + ')')
if ( Formato == 43 ):
  Boton43.setChecked (True)
Boton32=QtGui.QRadioButton('3:2 (' + str(TotalFormato32) + ')')
if ( Formato == 32 ):
  Boton32.setChecked (True)
BotonLibre=QtGui.QRadioButton('Libre (' + str(TotalFormatoLibre) + ')')
if ( Formato == 0 ):
  BotonLibre.setChecked (True)
GrupoBotonesFormato.addButton (Boton43)
GrupoBotonesFormato.addButton (Boton32)
GrupoBotonesFormato.addButton (BotonLibre)
CajaFormatoMedianas = QtGui.QHBoxLayout()
CajaFormato = QtGui.QVBoxLayout()
GrupoFormato = QtGui.QGroupBox(u"Formato")
CajaFormato.addWidget (Boton43)
CajaFormato.addWidget (Boton32)
CajaFormato.addWidget (BotonLibre)
GrupoFormato.setLayout (CajaFormato)
SpinMayor = QtGui.QSpinBox()
SpinMenor = QtGui.QSpinBox()
SpinCalidadMedianas = QtGui.QSpinBox()
SpinMayor.setMaximum (10000)
SpinMenor.setMaximum (10000)
SpinCalidadMedianas.setMinimum (CalidadMedianas)
SpinCalidadMedianas.setMaximum (100)
SpinMayor.setMinimum (1)
SpinMenor.setMinimum (1)
SpinMayor.setValue (Mayor)
SpinMenor.setValue (Menor)
SpinMayor.setSingleStep (IncrementoAnchura)
SpinMenor.setSingleStep (IncrementoAltura)
CajaMedianas = QtGui.QFormLayout()
CajaMedianas.addRow ('Mayor: ', SpinMayor)
CajaMedianas.addRow ('Menor: ', SpinMenor)
CajaMedianas.addRow ('Calidad: ', SpinCalidadMedianas)
GrupoMedianas = QtGui.QGroupBox(u"Medianas")
GrupoMedianas.setLayout (CajaMedianas)
CajaFormatoMedianas.addWidget (GrupoFormato)
CajaFormatoMedianas.addWidget (GrupoMedianas)

# La caja con los grupos Miniaturas e Índice
CajaMiniaturasIndice = QtGui.QHBoxLayout()
GrupoMiniaturas = QtGui.QGroupBox(u"Miniaturas")
GrupoIndice = QtGui.QGroupBox(u"Índice")
CajaMiniaturas = QtGui.QFormLayout()
CajaIndice = QtGui.QVBoxLayout()
SpinAnchura = QtGui.QSpinBox()
SpinAltura = QtGui.QSpinBox()
SpinColumnas = QtGui.QSpinBox()
SpinFilas = QtGui.QSpinBox()
SpinCalidadMiniaturas = QtGui.QSpinBox()
SpinAnchura.setMaximum (999)
SpinAltura.setMaximum (999)
SpinAnchura.setSingleStep (IncrementoAnchura)
SpinAltura.setSingleStep (IncrementoAltura)
SpinColumnas.setMaximum (99)
SpinFilas.setMaximum (99)
SpinCalidadMiniaturas.setMinimum (CalidadIndice)
SpinCalidadMiniaturas.setMaximum (100)
SpinAnchura.setMinimum (1)
SpinAltura.setMinimum (1)
SpinFilas.setMinimum (1)
SpinColumnas.setMinimum (1)
SpinAnchura.setValue (Anchura)
SpinAltura.setValue (Altura)
SpinFilas.setValue (Filas)
SpinColumnas.setValue (Columnas)
CajaMiniaturas.addRow ('Anchura: ', SpinAnchura)
CajaMiniaturas.addRow ('Altura: ', SpinAltura)
CajaMiniaturas.addRow ('Columnas: ', SpinColumnas)
CajaMiniaturas.addRow ('Filas: ', SpinFilas)
CajaMiniaturas.addRow ('Calidad: ', SpinCalidadMiniaturas)
EtiquetaAnchura = QtGui.QLabel (u'Anchura: ' + str(AnchuraInd))
EtiquetaAltura = QtGui.QLabel (u'Altura: ' + str(AlturaInd))
EtiquetaHuecos = QtGui.QLabel (u'Huecos: ' + str(Huecos))
CajaIndice.addWidget (EtiquetaAnchura)
CajaIndice.addWidget (EtiquetaAltura)
CajaIndice.addWidget (EtiquetaHuecos)
GrupoMiniaturas.setLayout (CajaMiniaturas)
GrupoIndice.setLayout (CajaIndice)
CajaMiniaturasIndice.addWidget (GrupoMiniaturas)
CajaMiniaturasIndice.addWidget (GrupoIndice)

# La caja con los botones principales
BotonPreparar = QtGui.QPushButton ("Preparar")
BotonCerrar = QtGui.QPushButton ("Cerrar")
CajaBotones = QtGui.QHBoxLayout()
CajaBotones.addWidget (BotonPreparar)
CajaBotones.addWidget (BotonCerrar)

# La caja con el desarrollo de la ejecución
EtiquetaDesarrollo = QtGui.QLabel (u'Esperando al usuario')
BarraProgreso = QtGui.QProgressBar()
BarraProgreso.setMinimum(0)
BarraProgreso.setMaximum(100)
CajaDesarrollo = QtGui.QVBoxLayout()
CajaDesarrollo.addStretch (1)
CajaDesarrollo.addWidget (EtiquetaDesarrollo)
CajaDesarrollo.addWidget (BarraProgreso)
GrupoDesarrollo = QtGui.QGroupBox(u"Desarrollo")
GrupoDesarrollo.setLayout (CajaDesarrollo)

# La caja con el estado del programa
EtiquetaEstado = QtGui.QLabel (u'El programa está preparado')
CajaEstado = QtGui.QVBoxLayout()
CajaEstado.addStretch (1)
CajaEstado.addWidget (EtiquetaEstado)
GrupoEstado = QtGui.QGroupBox(u"Estado")
GrupoEstado.setLayout (CajaEstado)

# El contenedor principal es un contenedor vertical
CajaVertical = QtGui.QVBoxLayout()
CajaVertical.addStretch (1)
CajaVertical.addWidget (GrupoDirectorio)
CajaVertical.addLayout (CajaFormatoMedianas)
CajaVertical.addLayout (CajaMiniaturasIndice)
CajaVertical.addLayout (CajaBotones)
CajaVertical.addWidget (GrupoDesarrollo)
CajaVertical.addWidget (GrupoEstado)
Ventana.setLayout (CajaVertical)

# Conectamos las señales con sus respuestas
BotonCerrar.clicked.connect (Ventana.close)
QtCore.QObject.connect (SpinAnchura, QtCore.SIGNAL("valueChanged(int)"), ManejaAnchura)
QtCore.QObject.connect (SpinAltura, QtCore.SIGNAL("valueChanged(int)"), ManejaAltura)
QtCore.QObject.connect (SpinFilas, QtCore.SIGNAL("valueChanged(int)"), ActualizaIndice)
QtCore.QObject.connect (SpinColumnas, QtCore.SIGNAL("valueChanged(int)"), ActualizaIndice)
QtCore.QObject.connect (SpinMayor, QtCore.SIGNAL("valueChanged(int)"), ManejaMayor)
QtCore.QObject.connect (SpinMenor, QtCore.SIGNAL("valueChanged(int)"), ManejaMenor)
QtCore.QObject.connect (BotonPreparar, QtCore.SIGNAL("clicked()"), Prepara)
QtCore.QObject.connect (Boton43, QtCore.SIGNAL("clicked()"), Cambia43)
QtCore.QObject.connect (Boton32, QtCore.SIGNAL("clicked()"), Cambia32)
QtCore.QObject.connect (BotonLibre, QtCore.SIGNAL("clicked()"), CambiaLibre)

# Mostramos la ventana
Ventana.setWindowTitle ('fn-prepara.py')
Ventana.setGeometry (10, 10, 10, 10)
Ventana.show()

# Cuando nos digan, terminaremos
sys.exit (Aplicacion.exec_())
