<?php

//--------------------------------------------------------------
// Fichero:  fn.php
// Objetivo: Rutinas PHP de apoyo de fn
// Fecha:    X.21.10.2015
// Autor:    Pedro Reina
//--------------------------------------------------------------

//------------------------------------------------
// Ficheros necesarios
//------------------------------------------------

require "config.php";
require "basedato.php";

//------------------------------------------------
// Funciones públicas
//------------------------------------------------

//--------------------------------------------------------------
// Emite el DTD de la página
function FN_EmiteDTD()
  {
  print "<!-- HTML 4.01 estricto -->\n";
  print "<!DOCTYPE HTML PUBLIC \"-//W3C//DTD HTML 4.01//EN\"\n";
  print "  \"http://www.w3.org/TR/html4/strict.dtd\">\n";
  }

//--------------------------------------------------------------
// Emite la cabecera de la página
function FN_EmiteCabecera ($Titulo)
  {
  global $Icono, $ArchivoCSS;

  $Siguiente = "";
  $JavaScript = "";

  // Si nos mandan un segundo parámetro, comprobamos qué es
  if ( func_num_args() == 2 )
    {
    // Si existe la cookie Tiempo hay que usar el visor automático
    if ( isset ($_COOKIE['Tiempo']) )
      {
      $Tiempo = $_COOKIE['Tiempo'];
      // Comprobamos si es un Tiempo válido
      $Tiempo = CompruebaTiempo ($Tiempo);
      if ( $Tiempo )
        {
        // Nos han pasado el enlace a la siguiente página
        $Enlace = func_get_arg (1);

        // Hay que retocarlo
        $Enlace = str_replace ("&amp;", "&", $Enlace);

        // Decimos al navegador que actualice la foto automáticamente
        $Siguiente = "<META HTTP-EQUIV=\"Refresh\" " .
                     "CONTENT=\"$Tiempo;URL=$Enlace\">";
        }
      }
    else
    // Estamos administrando y necesitamos un JavaScript
      { $JavaScript = func_get_arg (1); }
    }

  print "<HEAD>\n";
  print "<TITLE>$Titulo</TITLE>\n";
  print "<META HTTP-EQUIV=\"Content-Type\" CONTENT=\"text/html; charset=UTF-8\">\n";
  print $Siguiente;
  print "<LINK REL=\"icon\" HREF=\"$Icono\" TYPE=\"image/png\">\n";
  print "<LINK REL=\"StyleSheet\" HREF=\"$ArchivoCSS\" TYPE=\"text/css\">\n";
  if ( $JavaScript != "" )
    {
    print ("<SCRIPT TYPE=\"text/javascript\" SRC=\"$JavaScript\">");
    print ("</SCRIPT>\n");
    }
  print "</HEAD>";
  }

//--------------------------------------------------------------
// Emite el logotipo
function FN_EmiteLogotipo()
  {
  global $LogoVinculo, $LogoImagen, $LogoAlt, $LogoAnchura, $LogoAltura;

  print "<P CLASS=\"centrado\">\n";
  print "<A HREF=\"$LogoVinculo\">\n";
  print "<IMG SRC=\"$LogoImagen\" ALT=\"$LogoAlt\"";
  print "  CLASS=\"sinborde\" WIDTH=\"$LogoAnchura\" HEIGHT=\"$LogoAltura\">\n";
  print "</A></P>\n";
  }

//--------------------------------------------------------------
// Prepara un enlace
function FN_PreparaEnlace ($Serie, $Numero)
  {
  global $AcortarURL;

  if ( $AcortarURL )
    { $Respuesta = "$Serie.$Numero"; }

  else
    {
    if ( strcmp ($Numero, "listado") == 0 )
      { $Respuesta = "listado.php?Serie=$Serie"; }
    else
      { $Respuesta = "navegacion.php?Serie=$Serie&amp;Numero=$Numero"; }
    }

  return $Respuesta;
  }

//--------------------------------------------------------------
// Emite una imagen índice con un mapa
// El segundo parámetro es una función que crea la URL del enlace
function FN_EmiteIndiceMapa ($Serie, $CreaEnlace)
  {
  // Número de columnas y filas en la imagen índice
  $Orden = "rdjpgcom indices/$Serie.jpg";
  $Listado = `$Orden`;
  list ($TotalColumna, $TotalFila) = explode (" ", $Listado);

  // Dimensiones en píxeles de la imagen índice
  $TamanoIndice = GetImageSize ("indices/$Serie.jpg");
  $AnchuraIndice = $TamanoIndice[0];
  $AlturaIndice = $TamanoIndice[1];

  // Dimensiones de cada miniatura
  $AnchuraMini = $AnchuraIndice / $TotalColumna;
  $AlturaMini = $AlturaIndice / $TotalFila;

  // Coordenadas iniciales de las miniaturas
  $AbsArrIzq = 0;
  $OrdArrIzq = 0;
  $AbsAbaDer = $AnchuraMini - 1;
  $OrdAbaDer = $AlturaMini - 1;

  // Total de imágenes de la serie
  $Total = FN_CantidadSerie ($Serie);

  // La imagen irá centrada
  print "<P CLASS=\"centrado\">\n";
  print "<MAP NAME=\"$Serie\">\n";

  // Emitimos un área para cada miniatura
  for ( $i=1 ; $i<=$Total ; $i++ )
    {
    $Enlace = $CreaEnlace ($Serie, $i);
    print "<AREA COORDS=\"$AbsArrIzq,$OrdArrIzq,$AbsAbaDer,$OrdAbaDer\" " .
          "HREF=\"$Enlace\" TITLE=\"$i\" ALT=\"$i\">\n";
    $AbsArrIzq += $AnchuraMini;
    $AbsAbaDer += $AnchuraMini;
    if ( $AbsAbaDer > $AnchuraIndice )
      {
      $AbsArrIzq = 0;
      $AbsAbaDer = $AnchuraMini - 1;
      $OrdArrIzq += $AlturaMini;
      $OrdAbaDer += $AlturaMini;
      }
    }

  print "</MAP>\n";
  print "<IMG SRC=\"indices/$Serie.jpg\" ALT=\"Indice de $Serie\" " .
        "WIDTH=\"$AnchuraIndice\" HEIGHT=\"$AlturaIndice\" " .
        "CLASS=\"sinborde\" USEMAP=\"#$Serie\">\n";

  return ( $Total );
  }

//--------------------------------------------------------------
// Lee el comentario de una foto
function FN_LeeComentario ($Serie, $Nombre)
  {
  $ArrayCom = exif_read_data ("$Serie/reducidas/$Nombre.jpeg", 'COMMENT');
  $Comentario = $ArrayCom['COMMENT'][0];
  return ( $Comentario );
  }

//--------------------------------------------------------------

function FN_EmiteValidadores()
  {
  $CodigoHTML=<<<HTML

  <DIV CLASS="contenido">

  <A HREF="http://www.anybrowser.org/campaign/">
  <IMG SRC="./imagen/anybrowser.png" CLASS="sinborde"
       ALT="Mejor visto con cualquier navegador"
       TITLE="Mejor visto con cualquier navegador"
       HEIGHT="31" WIDTH="88">
  </A>

  <A HREF="http://validator.w3.org/check/referer">
  <IMG SRC="./imagen/valido-html401.png" CLASS="sinborde"
       ALT="HTML 4.01 válido" TITLE="HTML 4.01 válido"
       HEIGHT="31" WIDTH="88">
  </A>

  <A HREF="http://jigsaw.w3.org/css-validator/">
  <IMG SRC="./imagen/valido-css.png" CLASS="sinborde"
       ALT="CSS válido" TITLE="CSS válido"
       HEIGHT="31" WIDTH="88">
  </A>

  </DIV>

HTML;

  print $CodigoHTML;
  }

//--------------------------------------------------------------

// Rutina para comprobar el Tiempo que podemos recibir
function CompruebaTiempo ($Tiempo)
  {
  global $AutoValido;

  $Vale = 0;

  foreach ( $AutoValido as $AutoPosible )
    {
    if ( $AutoPosible[0] == $Tiempo )
      { $Vale = 1; }
    }

  if ( ! $Vale )  { $Tiempo = 0; }

  return $Tiempo;
  }

//--------------------------------------------------------------
// Obtiene una lista con los nombres y descripciones de las series visibles
function FN_ListaSeries()
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT nombre, descripcion FROM serie " .
              "WHERE visible=1 ORDER BY num DESC";

  // Hacemos la consulta
  $Lista = BD_ConsultaListaRegistro ($Consulta);

  // Devolvemos la lista
  return ( $Lista );
  }

//--------------------------------------------------------------
// Consulta cuántas series hay
function FN_TotalSerie()
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT COUNT(num) FROM serie";

  // Devolvemos el resultado
  return ( BD_ConsultaValor ($Consulta) );
  }

//--------------------------------------------------------------
// Consulta cuántas fotos hay
function FN_TotalFotos()
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT SUM(cantidad) FROM serie";

  // Devolvemos el resultado
  return ( BD_ConsultaValor ($Consulta) );
  }

//--------------------------------------------------------------
// Consulta cuántas fotos hay de media en cada serie
function FN_MediaFotos()
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT AVG(cantidad) FROM serie";

  // Obtenemos el valor decimal
  $Media = BD_ConsultaValor ($Consulta);

  // Lo convertimos a entero
  $Media = round ($Media, 0);

  // Devolvemos el resultado
  return ( $Media );
  }

//--------------------------------------------------------------
// Consulta el máximo valor de número de serie
function FN_MaxSerie()
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT MAX(num) FROM serie";

  // Devolvemos el resultado
  return ( BD_ConsultaValor ($Consulta) );
  }

//--------------------------------------------------------------
// Devuelve la descripción de una serie dado su nombre
function FN_DescripcionSerie ($Serie)
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT descripcion FROM serie WHERE nombre='$Serie'";

  // Devolvemos el resultado
  return ( BD_ConsultaValor ($Consulta) );
  }

//--------------------------------------------------------------
// Devuelve la cantidad de imágenes de una serie dado su nombre
function FN_CantidadSerie ($Serie)
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT cantidad FROM serie WHERE nombre='$Serie'";

  // Devolvemos el resultado
  return ( BD_ConsultaValor ($Consulta) );
  }

//--------------------------------------------------------------
// Devuelve el RowId de una serie dado su nombre
function FN_RowIdSerie ($Serie)
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT rowid FROM serie WHERE nombre='$Serie'";

  // Devolvemos el resultado
  return ( BD_ConsultaValor ($Consulta) );
  }

//--------------------------------------------------------------
// Inserta una nueva serie
function FN_InsertaSerie ($Num, $Nombre, $Descripcion, $Visible, $Cantidad)
  {
  // Colocamos físicamente los archivos
  ColocaArchivos ($Nombre);

  // Anotamos la nueva serie en la base de datos
  InsertaRegistro ($Num, $Nombre, $Descripcion, $Visible, $Cantidad);
  }

//--------------------------------------------------------------
// Modifica una serie
function FN_ActualizaSerie ($Num, $Nombre, $Descripcion, $Visible, $RowId)
  {
  // La consulta que haremos a la base de datos
  $Consulta = "UPDATE serie SET " .
              "num=$Num, nombre='$Nombre', " .
              "descripcion='$Descripcion', visible=$Visible " .
              "WHERE ROWID=$RowId";

  // La hacemos
  BD_EjecutaConsulta ($Consulta);
  }

//--------------------------------------------------------------
// Obtener una lista con todos los datos de todas las series
function FN_ListaCompletaSeries()
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT ROWID, * FROM serie ORDER BY num DESC";

  // Devolvemos la lista de registros obtenidos
  return ( BD_ConsultaListaRegistro ($Consulta) );
  }

//--------------------------------------------------------------
// Obtener una relación con los nombres sin extensión de las
// fotos de una serie
function FN_Relacion ($Serie)
  {
  $Relacion = array();

  // La lista con los nombres de las fotos
  $ListaFotos = glob ($Serie . "/*.jpg");
  foreach ( $ListaFotos as $Entrada )
    {
    // Eliminamos la extensión
    $Entrada = str_replace (".jpg", "", $Entrada);

    // Eliminamos el directorio
    $Datos = explode ('/', $Entrada);

    // Anotamos el nombre limpio
    array_push ($Relacion, $Datos[1]);
    }

  return ( $Relacion );
  }

//--------------------------------------------------------------
// Obtener los datos de una serie por su RowId
function FN_DatosSerie ($RowId)
  {
  // La consulta que haremos a la base de datos
  $Consulta = "SELECT * FROM serie WHERE ROWID=$RowId";

  // Devolvemos el registro con los datos
  return ( BD_ConsultaRegistro ($Consulta) );
  }

//------------------------------------------------
// Funciones privadas
//------------------------------------------------

//--------------------------------------------------------------
// Inserta en la base de datos el registro de una nueva serie
function InsertaRegistro ($Num, $Nombre, $Descripcion, $Visible, $Cantidad)
  {
  // La consulta que haremos a la base de datos
  $Consulta = "INSERT INTO serie " .
    "(num, nombre, descripcion, visible, cantidad) " .
    "VALUES ($Num, '$Nombre', '$Descripcion', $Visible, $Cantidad)";

  // La hacemos
  BD_EjecutaConsulta ($Consulta);
  }

// ----------------------------------------------
// Rutina para colocar los archivos de una serie
function ColocaArchivos ($Nombre)
  {
  global $DirCarga;

  // Creamos un nuevo directorio con un subdirectorio dentro
  mkdir ("$Nombre/reducidas", 0755, true);

  // Movemos el índice de la serie al directorio de índices
  rename ("$DirCarga/indice.jpg",  "indices/$Nombre.jpg");

  // Movemos las fotos reducidas
  $ListaMedianas = glob ($DirCarga . "/*.jpeg");
  foreach ( $ListaMedianas as $Archivo )
    {
    $DirNombre = explode ('/', $Archivo);
    $NombrePuro = $DirNombre[1];
    rename ($Archivo, "$Nombre/reducidas/$NombrePuro");
    }

  // Movemos las fotos originales
  $ListaFotos = glob ($DirCarga . "/*.jpg");
  foreach ( $ListaFotos as $Archivo )
    {
    $DirNombre = explode ('/', $Archivo);
    $NombrePuro = $DirNombre[1];
    rename ($Archivo, "$Nombre/$NombrePuro");
    }
  }

?>
