<?php

//--------------------------------------------------------------
// Fichero:  navegacion.php
// Objetivo: Dirigir la navegación por una serie de fotos
// Fecha:    X.21.10.2015
// Autor:    Pedro Reina
// Licencia: Dominio público
//--------------------------------------------------------------

//------------------------------------------------
// Ficheros necesarios
//------------------------------------------------

require_once "config.php";
require_once "fn.php";

//------------------------------------------------
// Llamada al programa principal
//------------------------------------------------

ProgramaPrincipal();

//------------------------------------------------
// Posibilidades para seguir
//------------------------------------------------

print "<DIV CLASS=\"cuadro\">\n";
print "  <DIV CLASS=\"titulo3\">Posibilidades para seguir</DIV>\n";
print "  <DIV CLASS=\"contenido\">\n";
print "  <UL>\n";
print "  <LI><A CLASS=\"texto\" HREF=\".\">Volver a Fotos digitales</A>\n";
print "  <LI><A CLASS=\"texto\" HREF=\"/\">Volver a la página principal</A>\n";
print "  </UL>\n";
print "  </DIV>\n";
print "</DIV>\n";

//------------------------------------------------
// Final de la página
//------------------------------------------------

FN_EmiteValidadores();

print "</BODY>\n";
print "</HTML>\n";

//------------------------------------------------
// Funciones
//------------------------------------------------

//------------------------------------------------
// La función que dirige el proceso
function ProgramaPrincipal()
  {
  // Si nos piden visor automático, tendremos definida
  // la variable $Auto mediante el método POST
  if ( isset ($_POST['Auto']) )
    {
    $Auto = $_POST['Auto'];
    // Comprobamos que el valor recibido es válido
    $Tiempo = CompruebaAuto ($Auto);

    // Si es válido, activamos el visor automático
    // y redirigimos el navegador a la foto pedida
    if ( $Tiempo )
      {
      $Serie = $_POST['Serie'];
      $Primera = $_POST['Primera'];
      $Enlace = FN_PreparaEnlace ($Serie, $Primera);
      $Enlace = str_replace ("&amp;", "&", $Enlace);
      setcookie ('Tiempo', $Tiempo);
      header ('location: ' . $Enlace);
      }
    }

  // Si no, nos han pasado las variables por la URL
  else
    {
    $Serie = $_GET['Serie'];
    $Numero = $_GET['Numero'];

    // El número 0 significa el índice
    if ( $Numero == 0 )
      { MuestraIndice ($Serie); }

    // Cualquier otro número es una foto
    else
      {
      $Existe = MuestraFoto ($Serie, $Numero);
      if ( !$Existe )
        { MuestraIndice ($Serie); }
      }
    }
  }

//------------------------------------------------
// Rutina para mostrar el índice
function MuestraIndice ($Serie)
  {
  global $AutoValido;

  $YoMismo = $_SERVER['PHP_SELF'];

  // Desactivamos el visor automático
  setcookie ('Tiempo', "", time() - 3600);

  FN_EmiteDTD();
  print "<HTML>\n";

  // La cabecera del archivo HTML
  FN_EmiteCabecera ("Fotos digitales $Serie");

  // Consultamos la descripción de la serie
  $Descripcion = FN_DescripcionSerie ($Serie);

  // Comienzo de la parte de la página que ve el usuario
  print "<BODY>\n";
  print "<DIV CLASS=\"cuadro\">\n";
  print "<DIV CLASS=\"titulo2\">Fotos digitales, serie $Serie</DIV>\n";
  print "<DIV CLASS=\"contenido\">\n";
  print $Descripcion;

  // Emitimos la imagen índice con un mapa
  $Total = FN_EmiteIndiceMapa ($Serie, 'FN_PreparaEnlace');
  print "</DIV>\n";
  print "</DIV>\n";

  // Emitimos los controles para lanzar el visor automático
  print "<DIV CLASS=\"cuadro\">\n";
  print "<DIV CLASS=\"titulo3\">Visor automático</DIV>\n";
  print "<FORM ACTION=\"$YoMismo\" METHOD=\"POST\">\n";
  print "<DIV CLASS=\"contenido\">\n";
  print "<INPUT TYPE=\"HIDDEN\" NAME=\"Serie\" VALUE=\"$Serie\">\n";
  print "Intervalo:\n";
  print "<SELECT NAME=\"Auto\">\n";
  foreach ( $AutoValido as $AutoPosible )
    { print "<OPTION>$AutoPosible[1]</OPTION>\n"; }
  print "</SELECT>\n";
  print "&nbsp;&nbsp;Primera:\n";
  print "<SELECT NAME=\"Primera\">\n";
  for ( $i=1 ; $i<=$Total ; $i++ )
    { print "<OPTION>$i</OPTION>\n"; }
  print "</SELECT>\n";
  print "&nbsp;&nbsp;\n";
  print "<INPUT TYPE=\"submit\" NAME=\"Comenzar\" VALUE=\" Comenzar \">\n";
  print "</DIV>\n";
  print "</FORM>\n";
  print "</DIV>\n";

  // Vínculos directos a los directorios de imágenes
  $EnlaceListado = FN_PreparaEnlace ($Serie, "listado");
  print "<DIV CLASS=\"cuadro\">\n";
  print "<DIV CLASS=\"titulo3\">Enlace técnico</DIV>\n";
  print "<DIV CLASS=\"contenido\">\n";
  print "Puedes acceder directamente al directorio con las imágenes " .
        "por si deseas descargar varias a la vez:\n";
  print "<A CLASS=\"texto\" HREF=\"$EnlaceListado\">$Serie</A>\n";
  print "</DIV>\n";

  print "</DIV>\n";
  }

//------------------------------------------------
// Rutina para mostrar la foto pedida
// Devolvemos verdadero o falso según exista la foto pedida
function MuestraFoto ($Serie, $Numero)
  {
  // Montamos una relación con los nombres de las fotos
  // que hay en el directorio de la serie
  $Relacion = FN_Relacion ($Serie);

  // Nombre del archivo con la foto
  $NombreArchivo = $Relacion[$Numero-1];

  // Preparamos la respuesta que vamos a dar
  $Respuesta = false;

  // Dimensiones de la imagen pedida
  // Si la llamada falla, es que la imagen no se puede mostrar,
  // probablemente porque no existe
  $TamanoImagen = @GetImageSize ("$Serie/reducidas/$NombreArchivo.jpeg");

  // Si se encuentra la imagen, la mostramos
  if ( $TamanoImagen )
    {
    $Respuesta = true;

    // Las dimensiones las lee PHP
    $DimensionesImagen = $TamanoImagen[3];

    // Calculamos las fotos anterior y siguiente
    // Un valor 0 significa volver al índice
    $Anterior = $Numero - 1;
    $Siguiente = $Numero + 1;
    if ( $Siguiente == count ($Relacion)+1 )
      { $Siguiente = 0; }

    // Los enlaces al índice y las fotos anterior y siguiente
    $EnlaceIndice = FN_PreparaEnlace ($Serie, 0);
    $EnlaceAnterior = FN_PreparaEnlace ($Serie, $Anterior);
    $EnlaceSiguiente = FN_PreparaEnlace ($Serie, $Siguiente);

    // Las flechas al índice y a las fotos anterior y siguiente
    if ( rand (0, 20) )
      { $FlechaIzquierda = "imagen/izquierda.png"; }
    else
      { $FlechaIzquierda = "imagen/izquierda1.png"; }
    if ( rand (0, 20) )
      { $FlechaArriba = "imagen/arriba.png"; }
    else
      { $FlechaArriba = "imagen/arriba1.png"; }
    if ( rand (0, 20) )
      { $FlechaDerecha = "imagen/derecha.png"; }
    else
      { $FlechaDerecha = "imagen/derecha1.png"; }

    // Buscamos la descripción de la serie en la base de datos
    $Descripcion = FN_DescripcionSerie ($Serie);

    FN_EmiteDTD();
    print "<HTML>\n";

    FN_EmiteCabecera ("Fotos digitales $Serie.$Numero", $EnlaceSiguiente);

    $CodigoHTML=<<<HTML

    <DIV CLASS="cuadro">

      <DIV CLASS="titulo2">

        <SPAN STYLE="float:left; width:12em; text-align:left">
        Serie $Serie
        </SPAN>

        <SPAN STYLE="float:right; width:12em; text-align:right">
        Número $Numero
        </SPAN>

        Fotos digitales

      </DIV>

      <DIV CLASS="contenido">$Descripcion</DIV>

    </DIV>

    <DIV CLASS="cuadro">

      <DIV CLASS="contenido">

        <SPAN STYLE="float:left; text-align:left">

        <A HREF="$EnlaceAnterior">
        <SPAN CLASS="enlace"
              STYLE="background-image: url($FlechaIzquierda)">
        </SPAN></A>

        <A HREF="$EnlaceIndice">
        <SPAN CLASS="enlace"
              STYLE="background-image: url($FlechaArriba)">
        </SPAN></A>

        <A HREF="$EnlaceSiguiente">
        <SPAN CLASS="enlace"
              STYLE="background-image: url($FlechaDerecha)">
        </SPAN></A>

        </SPAN>

        <SPAN STYLE="float:right; text-align:right">

        <A HREF="$EnlaceAnterior">
        <SPAN CLASS="enlace"
              STYLE="background-image: url($FlechaIzquierda)">
        </SPAN></A>

        <A HREF="$EnlaceIndice">
        <SPAN CLASS="enlace"
              STYLE="background-image: url($FlechaArriba)">
        </SPAN></A>

        <A HREF="$EnlaceSiguiente">
        <SPAN CLASS="enlace"
              STYLE="background-image: url($FlechaDerecha)">
        </SPAN></A>

        </SPAN>

        <P CLASS="centrado">
        <A HREF="$Serie/$NombreArchivo.jpg">
        <IMG SRC="$Serie/reducidas/$NombreArchivo.jpeg" $DimensionesImagen
             ALT="$Numero" CLASS="sinborde">
        </A>

      </DIV>

    </DIV>

HTML;
    print $CodigoHTML;

    // Si hay un comentario en la foto, lo mostramos
    $Comentario = FN_LeeComentario ($Serie, $NombreArchivo);

    if ( strlen ($Comentario) )
      {
      print "<DIV CLASS=\"cuadro\">\n";
      print "<DIV CLASS=\"titulo2\">Comentario</DIV>\n";
      print "<DIV CLASS=\"contenido\">\n";
      print $Comentario;
      print "</DIV>\n";
      print "</DIV>\n";
      }

    // Obtenemos y mostramos la información técnica de la foto
    $Orden = "jhead $Serie/$NombreArchivo.jpg";
    $Listado = rtrim(`$Orden`);
    print "<DIV CLASS=\"cuadro\">\n";
    print "<DIV CLASS=\"titulo3\">Información técnica de la foto</DIV>\n";
    print "<DIV CLASS=\"contenido\">\n";
    print "<PRE>$Listado</PRE>\n";
    print "</DIV>\n";
    print "</DIV>\n";
    }

  return ( $Respuesta );
  }

//------------------------------------------------
// Rutina para comprobar la entrada Auto que podemos recibir
function CompruebaAuto ($Auto)
  {
  global $AutoValido;

  $Vale = 0;

  foreach ( $AutoValido as $AutoPosible )
    {
    if ( strcmp ($AutoPosible[1], $Auto) == 0 )
      {
      $Vale = 1;
      $Tiempo = $AutoPosible[0];
      }
    }

  if ( ! $Vale )  { $Tiempo = 0; }

  return ( $Tiempo );
  }

?>
